openapi

package
v0.0.0-...-7b9de4d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 19, 2025 License: GPL-3.0 Imports: 0 Imported by: 0

Documentation

Overview

Package openapi provides primitives to interact with the openapi HTTP API.

Code generated by github.com/oapi-codegen/oapi-codegen/v2 version (devel) DO NOT EDIT.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Error

type Error struct {
	// Details Additional details about the error. Ignored if [errors] is used.
	Details *interface{} `json:"details,omitempty"`

	// Errors An array of errors that caused this error. If this is populated, then [details] is omitted.
	Errors []Error `json:"errors,omitempty"`

	// Internal Whether the error is internal
	Internal *bool `json:"internal,omitempty"`

	// InternalCode An internal code for the error (useless for clients)
	InternalCode *string `json:"internalCode,omitempty"`

	// Message A message describing the error
	Message string `json:"message"`
}

Error defines model for Error.

type ErrorResponse

type ErrorResponse = Error

ErrorResponse defines model for ErrorResponse.

type RateLimitedResponse

type RateLimitedResponse = Error

RateLimitedResponse defines model for RateLimitedResponse.

Jump to